@@ -8,7 +8,7 @@
 // according to those terms.
 
 use crate::{RegisteredType, TypesMeta};
-use heck::CamelCase;
+use heck::ToUpperCamelCase;
 use proc_macro2::{Span, TokenStream};
 use std::borrow::Cow;
 use std::collections::HashMap;
@@ -780,7 +780,7 @@ pub(super) fn write_specialization_constants<'a>(
     let struct_name = if shared_constants {
         format_ident!("SpecializationConstants")
     } else {
-        format_ident!("{}SpecializationConstants", shader.to_camel_case())
+        format_ident!("{}SpecializationConstants", shader.to_upper_camel_case())
     };
 
     // For multi-constants mode registration mechanism skipped
@@ -814,7 +814,7 @@ pub(super) fn write_specialization_constants<'a>(
             let constant_id = spec_const.constant_id;
             let rust_size = spec_const.rust_size;
             map_entries.push(quote! {
-                SpecializationMapEntry {
+                ::vulkano::shader::SpecializationMapEntry {
                     constant_id: #constant_id,
                     offset: #curr_offset,
                     size: #rust_size,
@@ -857,9 +857,9 @@ pub(super) fn write_specialization_constants<'a>(
             }
         }
 
-        unsafe impl SpecConstsTrait for #struct_name {
-            fn descriptors() -> &'static [SpecializationMapEntry] {
-                static DESCRIPTORS: [SpecializationMapEntry; #num_map_entries] = [
+        unsafe impl ::vulkano::shader::SpecializationConstants for #struct_name {
+            fn descriptors() -> &'static [::vulkano::shader::SpecializationMapEntry] {
+                static DESCRIPTORS: [::vulkano::shader::SpecializationMapEntry; #num_map_entries] = [
                     #( #map_entries ),*
                 ];
                 &DESCRIPTORS
